Imports System.Collections.Generic
Imports System.Collections.ObjectModel
Imports System.ComponentModel
Imports System.Data
Imports System.Drawing
Imports System.Linq
Imports System.Text
Imports System.Windows.Forms

Imports MindFusion.Charting.WinForms
Imports MindFusion.Charting.Components
Imports MindFusion.Charting

Imports LinearGradientBrush = MindFusion.Drawing.LinearGradientBrush


Partial Public Class MainForm
	Inherits Form
	Private dashboard As Dashboard

	Public Sub New()
		InitializeComponent()

		dashboard = New Dashboard()
		dashboard.Dock = DockStyle.Fill
		Controls.Add(dashboard)

		Dim builder As New LayoutBuilder(dashboard)

		dashboard.LayoutPanel.Children.Add(New TextComponent() With { _
		 .Text = "TITLE TEXT", _
		 .FontName = "Times New Roman", _
		 .FontStyle = System.Drawing.FontStyle.Underline, _
		 .FontSize = 20.4, _
		 .HorizontalAlignment = LayoutAlignment.Center _
		})

		Dim grid As New GridPanel()

		Dim linePlot As New Plot2D() With { _
		 .Background = New LinearGradientBrush(Color.White, Color.FromArgb(224, 224, 224)) With { _
		 .Angle = 90 _
		 } _
		}

		Dim barPlot As New Plot2D()
		Dim radarPlot As New RadarPlot()
		Dim polarPlot As New PolarPlot()
		Dim plot3d1 As New Plot3D()
		Dim plot3d2 As New Plot3D()
		Dim plot3d3 As New Plot3D()
		Dim plot4 As New Plot2D()

		linePlot.XAxis = New Axis()
		linePlot.XAxis.MinValue = 0
		linePlot.XAxis.MaxValue = 15
		linePlot.XAxis.Interval = 1
		linePlot.XAxis.Title = "When?"

		linePlot.YAxis = New Axis()
		linePlot.YAxis.MinValue = 0
		linePlot.YAxis.MaxValue = 35
		linePlot.YAxis.Interval = 5
		linePlot.YAxis.Title = "How many thousands?"

		barPlot.XAxis = New Axis()
		barPlot.XAxis.MinValue = -1
		barPlot.XAxis.MaxValue = 15
		barPlot.XAxis.Interval = 1
		barPlot.XAxis.Title = "When?"

		barPlot.YAxis = New Axis()
		barPlot.YAxis.MinValue = 0
		barPlot.YAxis.MaxValue = 35
		barPlot.YAxis.Interval = 5
		barPlot.YAxis.Title = "How many thousands?"

		Dim data1 As New BarSeries(
		 New List(Of Double)() From {10, 15, 17, 16, 20, 15, 14, 13, 10, 17, 22, 25, 25, 25, 21, 21},
		 Nothing, Nothing,
		 New List(Of String)() From { _
		 "nov" & vbLf & "2014", _
		 "dec" & vbLf & "2014", _
		 "jan" & vbLf & "2015", _
		 "feb" & vbLf & "2015", _
		 "mar" & vbLf & "2015", _
		 "apr" & vbLf & "2015", _
		 "may" & vbLf & "2015", _
		 "jun" & vbLf & "2015", _
		 "jul" & vbLf & "2015", _
		 "aug" & vbLf & "2015", _
		 "sep" & vbLf & "2015", _
		 "oct" & vbLf & "2015", _
		 "nov" & vbLf & "2015", _
		 "dec" & vbLf & "2015", _
		 "jan" & vbLf & "2016", _
		 "feb" & vbLf & "2016" _
		}) With { _
		 .Title = "LP Vinyl" _
		}
		Dim data2 As New BarSeries(
		 New List(Of Double)() From {13, 13, 14, 16, 23, 25, 20, 19, 16, 17, 15, 13, 13, 17, 18, 21},
		   Nothing, Nothing) With { _
		 .Title = "CD" _
		}
		Dim data3 As New BarSeries(
		 New List(Of Double)() From {29, 28, 29, 31, 33, 35, 33, 27, 28, 28, 27, 29, 29, 31, 33, 29},
		 Nothing, Nothing) With { _
		 .Title = "MP3" _
		}

		Dim lineRenderer As New LineRenderer(
		 New ObservableCollection(Of Series)() From {data1, data2, data3})

		Dim barDataRenderer As New BarRenderer(
		 New ObservableCollection(Of Series)() From { data1, data2, data3 })

		Dim radarDataRenderer As New RadarRenderer(
		 New ObservableCollection(Of Series)() From { data1, data2, data3 })

		Dim pieDataRenderer As New PieRenderer(data1, 1)
		Dim bar3DDataRenderer As New BarRenderer3D(
		 New ObservableCollection(Of Series)() From {data1, data2, data3})

		Dim horizontalBar3DDataRenderer As New BarRenderer(
		 New ObservableCollection(Of Series)() From {data1, data2, data3})

		Dim barStack3DRenderer As New BarStackRenderer3D(
		 New ObservableCollection(Of Series)() From {data1, data2, data3})

		Dim barOverlay3DRenderer As New BarOverlayRenderer3D(
		 New ObservableCollection(Of Series)() From { data1, data2, data3 })

		lineRenderer.SeriesStyle = New PerSeriesStyle() With {
		 .Strokes = New List(Of MindFusion.Drawing.Brush)() From {
			New MindFusion.Drawing.SolidBrush(Color.FromArgb(102, 154, 204)),
			New MindFusion.Drawing.SolidBrush(Color.FromArgb(0, 52, 102)),
			New MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0))
		 },
		 .Fills = New List(Of MindFusion.Drawing.Brush)() From {
			New MindFusion.Drawing.SolidBrush(Color.FromArgb(102, 154, 204)),
			New MindFusion.Drawing.SolidBrush(Color.FromArgb(0, 52, 102)),
			New MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0))
		 },
		 .StrokeThicknesses = New List(Of Double)() From {3.0}
		}

		barDataRenderer.SeriesStyle = New PerSeriesStyle() With {
		 .Fills = New List(Of MindFusion.Drawing.Brush)() From {
			New MindFusion.Drawing.SolidBrush(Color.FromArgb(102, 154, 204)),
			New MindFusion.Drawing.SolidBrush(Color.FromArgb(0, 52, 102)),
			New MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0))
		 }
		}

		bar3DDataRenderer.SeriesStyle = New PerSeriesStyle() With {
		 .Fills = New List(Of MindFusion.Drawing.Brush)() From {
		   New MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(224, 233, 233))),
		   New MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(102, 154, 204))),
		   New MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(0, 52, 102)))
		 },
		 .StrokeThicknesses = New List(Of Double)() From {
		  1
		 }
		}

		horizontalBar3DDataRenderer.SeriesStyle = New PerSeriesStyle() With {
		 .Fills = New List(Of MindFusion.Drawing.Brush)() From {
		   New MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(224, 233, 233))),
		   New MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(102, 154, 204))),
		   New MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(0, 52, 102)))
		 },
		 .StrokeThicknesses = New List(Of Double)() From {
		  1
		 }
		}
		horizontalBar3DDataRenderer.HorizontalBars = True

		barOverlay3DRenderer.SeriesStyle = New PerSeriesStyle() With {
		 .Fills = New List(Of MindFusion.Drawing.Brush)() From {
		   New MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(224, 233, 233))),
		   New MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(102, 154, 204))),
		   New MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(0, 52, 102)))
		 },
		 .StrokeThicknesses = New List(Of Double)() From {
		  1
		 }
		}

		barStack3DRenderer.SeriesStyle = New PerSeriesStyle() With {
		 .Fills = New List(Of MindFusion.Drawing.Brush)() From {
		   New MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(224, 233, 233))),
		   New MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(102, 154, 204))),
		   New MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(0, 52, 102)))
		 },
		 .StrokeThicknesses = New List(Of Double)() From {
		  1
		 }
		}
		radarDataRenderer.SeriesStyle = New PerSeriesStyle() With {
		 .Strokes = New List(Of MindFusion.Drawing.Brush)() From {
			New MindFusion.Drawing.SolidBrush(Color.FromArgb(102, 154, 204)),
			New MindFusion.Drawing.SolidBrush(Color.FromArgb(0, 52, 102)),
			New MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0))
		 },
		 .Fills = New List(Of MindFusion.Drawing.Brush)() From {
			New MindFusion.Drawing.SolidBrush(Color.FromArgb(102, 154, 204)),
			New MindFusion.Drawing.SolidBrush(Color.FromArgb(0, 52, 102)),
			New MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0))
		 },
		 .StrokeThicknesses = New List(Of Double)() From {
		  5
		 }
		}

		radarDataRenderer.AreaOpacity = 0.2
		radarPlot.DefaultAxis.MinValue = 0
		radarPlot.DefaultAxis.MaxValue = 35
		radarPlot.DefaultAxis.Interval = 5
		radarPlot.AxisOptions = New RadarAxisOptions(radarPlot.DefaultAxis)
		radarPlot.AxisOptions.ShowSeriesLabels = True
		radarPlot.AxisOptions.AxisStroke = New MindFusion.Drawing.SolidBrush(Color.LightGray)
		radarPlot.DefaultAxis.Title = ""

		linePlot.SeriesRenderers.Add(lineRenderer)
		barPlot.SeriesRenderers.Add(barDataRenderer)
		radarPlot.SeriesRenderers.Add(radarDataRenderer)
		polarPlot.SeriesRenderers.Add(pieDataRenderer)
		plot3d1.SeriesRenderers.Add(bar3DDataRenderer)
		plot3d2.SeriesRenderers.Add(barStack3DRenderer)
		plot3d3.SeriesRenderers.Add(barOverlay3DRenderer)
		plot4.SeriesRenderers.Add(horizontalBar3DDataRenderer)

		plot3d1.XAxis = New Axis() With { _
		 .MinValue = 0, _
		 .MaxValue = 5, _
		 .Interval = 1, _
		 .Title = "Months" _
		}
		plot3d1.YAxis = New Axis() With { _
		 .MinValue = 0, _
		 .MaxValue = 40, _
		 .Interval = 5, _
		 .Title = "Thousands" _
		}

		plot3d2.XAxis = InlineAssignHelper(plot3d3.XAxis, plot3d1.XAxis)
		plot3d2.YAxis = InlineAssignHelper(plot3d3.YAxis, plot3d1.YAxis)
		plot3d2.YAxis = New Axis() With { _
		 .MinValue = 0, _
		 .MaxValue = 100, _
		 .Interval = 5, _
		 .Title = "Thousands" _
		}

		plot4.YAxis = New Axis() With { _
		 .MinValue = 0, _
		 .MaxValue = 4, _
		 .Interval = 1, _
		 .Title = "Months" _
		}
		plot4.XAxis = New Axis() With { _
		 .MinValue = 0, _
		 .MaxValue = 40, _
		 .Interval = 5, _
		 .Title = "Thousands" _
		}

		plot4.VerticalScroll = True

		Dim xAxisRenderer As New XAxisRenderer(plot4.XAxis) With {
		 .AxisStroke = New MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0)),
		 .AxisStrokeThickness = 3,
		 .TitleBrush = New MindFusion.Drawing.SolidBrush(Color.FromArgb(90, 121, 165)),
		 .TitleFontName = "Courier New",
		 .TitleFontSize = 15
		}
		Dim yAxisRenderer As New YAxisRenderer(plot4.YAxis) With {
		 .AxisStroke = New MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0)),
		 .AxisStrokeThickness = 3,
		 .TitleBrush = New MindFusion.Drawing.SolidBrush(Color.FromArgb(90, 121, 165)),
		 .TitleFontName = "Courier New",
		 .TitleFontSize = 15
		}

		Dim panel1 As GridPanel = builder.CreatePlotWithBottomAndLeftAxes(linePlot, New XAxisRenderer(linePlot.XAxis) With { _
		 .LabelsSource = linePlot, _
		 .ShowCoordinates = False, _
		 .LabelFontSize = 6 _
		}, New YAxisRenderer(linePlot.YAxis))
		Dim panel2 As GridPanel = builder.CreatePlotWithBottomAndRightAxes(barPlot, New XAxisRenderer(barPlot.XAxis) With { _
		 .LabelsSource = linePlot, _
		 .ShowCoordinates = False, _
		 .LabelFontSize = 6 _
		}, New YAxisRenderer(barPlot.YAxis))
		Dim panel3 As GridPanel = builder.CreatePlotWithTopAndRightAxes(plot3d1, New XAxisRenderer(plot3d1.XAxis) With { _
		 .ShowCoordinates = False, _
		 .TitleBrush = New MindFusion.Drawing.SolidBrush(Color.Green), _
		 .TitleFontName = "Verdana", _
		 .TitleFontSize = 10 _
		}, New YAxisRenderer(plot3d1.YAxis) With { _
		 .TitleBrush = New MindFusion.Drawing.SolidBrush(Color.Green), _
		 .TitleFontName = "Verdana", _
		 .TitleFontSize = 10 _
		})
		Dim panel4 As GridPanel = builder.CreatePlotWithTopAndLeftAxes(plot3d2, New XAxisRenderer(plot3d2.XAxis) With { _
		 .TitleBrush = New MindFusion.Drawing.SolidBrush(Color.Blue), _
		 .TitleFontName = "Times New Roman", _
		 .TitleFontSize = 15 _
		}, New YAxisRenderer(plot3d2.YAxis) With { _
		 .TitleBrush = New MindFusion.Drawing.SolidBrush(Color.Blue), _
		 .TitleFontName = "Times New Roman", _
		 .TitleFontSize = 15, _
		 .TitleFontStyle = FontStyle.Bold _
		})
		Dim panel5 As GridPanel = builder.CreatePlotWithTopAndRightAxes(plot3d3, New XAxisRenderer(plot3d3.XAxis) With { _
		 .TitleBrush = New MindFusion.Drawing.SolidBrush(Color.Purple), _
		 .TitleFontName = "Courier New", _
		 .TitleFontSize = 12 _
		}, New YAxisRenderer(plot3d3.YAxis) With { _
		 .TitleBrush = New MindFusion.Drawing.SolidBrush(Color.Purple), _
		 .TitleFontName = "Courier New", _
		 .TitleFontSize = 12 _
		})
		Dim panel6 As GridPanel = builder.CreatePlotWithTopAndLeftAxes(plot4, xAxisRenderer, yAxisRenderer)

		panel1.Margin = InlineAssignHelper(panel2.Margin, InlineAssignHelper(panel3.Margin, InlineAssignHelper(panel4.Margin, InlineAssignHelper(panel5.Margin, InlineAssignHelper(panel6.Margin, New Margins(5))))))


		grid.Columns.Add(New GridColumn())
		grid.Rows.Add(New GridRow())

		Dim miniGrid As New GridPanel()
		miniGrid.Columns.Add(New GridColumn())
		miniGrid.Rows.Add(New GridRow())

		panel1.GridColumn = 0
		panel1.GridRow = 0
		panel2.GridColumn = 1
		panel2.GridRow = 0
		radarPlot.GridColumn = 0
		radarPlot.GridRow = 1

		polarPlot.GridColumn = 0
		polarPlot.GridRow = 0
		panel3.GridColumn = 1
		panel3.GridRow = 0
		panel4.GridColumn = 0
		panel4.GridRow = 1
		panel5.GridColumn = 1
		panel5.GridRow = 1
		panel6.GridColumn = 0
		panel6.GridRow = 0

		Dim legend As New LegendRenderer()
		legend.Content.Add(lineRenderer)

		grid.Children.Add(panel1)
		grid.Children.Add(panel2)
		grid.Children.Add(radarPlot)
		grid.Children.Add(miniGrid)

		miniGrid.Children.Add(panel3)
		miniGrid.Children.Add(panel4)
		miniGrid.Children.Add(panel5)
		miniGrid.Children.Add(panel6)
		miniGrid.GridColumn = 1
		miniGrid.GridRow = 1

		dashboard.LayoutPanel.Children.Add(grid)
		dashboard.RootPanel.Children.Add(legend)
	End Sub
	Private Shared Function InlineAssignHelper(Of T)(ByRef target As T, value As T) As T
		target = value
		Return value
	End Function
End Class
